==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_upload_handler.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_upload_handler.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("LANUPLOAD_1", "The filetype");
define("LANUPLOAD_2", "is not allowed and has been deleted.");
define("LANUPLOAD_3", "Successfully uploaded");
define("LANUPLOAD_4", "Either destination folder does not exist or is not writable. (chmod 777)");
define("LANUPLOAD_5", "The uploaded file exceeds the upload_max_filesize directive in php.ini.");
define("LANUPLOAD_6", "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the html form.");
define("LANUPLOAD_7", "The uploaded file was only partially uploaded.");
define("LANUPLOAD_8", "No file was uploaded.");
define("LANUPLOAD_9", "Uploaded file size 0 bytes");
define("LANUPLOAD_10", "Upload failed [Duplicate filename] - A file with the same name already exists.");
define("LANUPLOAD_11", "The file did not upload. Filename: ");
define("LANUPLOAD_12", "Error");
define("LANUPLOAD_13", "Missing temporary folder");
define("LANUPLOAD_14", "File write failed");
define("LANUPLOAD_15", "Upload not allowed");
define("LANUPLOAD_16", "Unknown Error");
define("LANUPLOAD_17", "Invalid name for uploaded file");
define("LANUPLOAD_18", "The uploaded file exceeds allowable limits.");
define("LANUPLOAD_19", "Too many files uploaded - excess deleted.");


?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_upload_handler.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_upload_handler.php $
|     $Revision: 11678 $
|     $Id: lan_upload_handler.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("LANUPLOAD_1", "The filetype");
define("LANUPLOAD_2", "is not allowed and has been deleted.");
define("LANUPLOAD_3", "Successfully uploaded");
define("LANUPLOAD_4", "Either destination folder does not exist or is not writable. (chmod 777)");
define("LANUPLOAD_5", "The uploaded file exceeds the upload_max_filesize directive in php.ini.");
define("LANUPLOAD_6", "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the html form.");
define("LANUPLOAD_7", "The uploaded file was only partially uploaded.");
define("LANUPLOAD_8", "No file was uploaded.");
define("LANUPLOAD_9", "Uploaded file size 0 bytes");
define("LANUPLOAD_10", "Upload failed [Duplicate filename] - A file with the same name already exists.");
define("LANUPLOAD_11", "The file did not upload. Filename: ");
define("LANUPLOAD_12", "Error");
define("LANUPLOAD_13", "Missing temporary folder");
define("LANUPLOAD_14", "File write failed");
define("LANUPLOAD_15", "Upload not allowed");
define("LANUPLOAD_16", "Unknown Error");
define("LANUPLOAD_17", "Invalid name for uploaded file");
define("LANUPLOAD_18", "The uploaded file exceeds allowable limits.");
define("LANUPLOAD_19", "Too many files uploaded - excess deleted.");


?>
